Stan Math Library: stan/math/rev/mat/fun/dot_product.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
dot_product.hpp File Reference
`#include <stan/math/prim/mat/fun/Eigen.hpp>`
`#include <stan/math/prim/mat/fun/typedefs.hpp>`
`#include <stan/math/prim/mat/err/check_vector.hpp>`
`#include <stan/math/prim/mat/err/check_matching_sizes.hpp>`
`#include <stan/math/prim/scal/fun/value_of.hpp>`
`#include <stan/math/rev/core.hpp>`
`#include <stan/math/rev/mat/fun/typedefs.hpp>`
`#include <stan/math/rev/scal/fun/value_of.hpp>`
`#include <boost/utility/enable_if.hpp>`
`#include <boost/type_traits.hpp>`
`#include <vector>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T1 , int R1, int C1, typename T2 , int R2, int C2>
boost::enable_if_c< boost::is_same< T1, var >::value||boost::is_same< T2, var >::value, var >::type | stan::math::dot_product (const Eigen::Matrix< T1, R1, C1 > &v1, const Eigen::Matrix< T2, R2, C2 > &v2)
| Returns the dot product. More...
template<typename T1 , typename T2 >
boost::enable_if_c< boost::is_same< T1, var >::value||boost::is_same< T2, var >::value, var >::type | stan::math::dot_product (const T1 *v1, const T2 *v2, size_t length)
| Returns the dot product. More...
template<typename T1 , typename T2 >
boost::enable_if_c< boost::is_same< T1, var >::value||boost::is_same< T2, var >::value, var >::type | stan::math::dot_product (const std::vector< T1 > &v1, const std::vector< T2 > &v2)
| Returns the dot product. More...

## Variable Documentation

size_t length_

Definition at line 38 of file dot_product.hpp.

dot_product_store_type<T1>::type v1_

Definition at line 36 of file dot_product.hpp.

dot_product_store_type<T2>::type v2_

Definition at line 37 of file dot_product.hpp.

[ Stan Home Page ] © 2011–2016, Stan Development Team.